@@ -2,7 +2,7 @@ from .__version__ import __description__, __title__, __version__
 from ._api import delete, get, head, options, patch, post, put, request, stream
 from ._auth import Auth, BasicAuth, DigestAuth
 from ._client import AsyncClient, Client
-from ._config import Limits, PoolLimits, Proxy, Timeout, create_ssl_context
+from ._config import Limits, Proxy, Timeout, create_ssl_context
 from ._exceptions import (
     CloseError,
     ConnectError,
@@ -21,7 +21,6 @@ from ._exceptions import (
     ReadError,
     ReadTimeout,
     RemoteProtocolError,
-    RequestBodyUnavailable,
     RequestError,
     RequestNotRead,
     ResponseClosed,
@@ -38,7 +37,6 @@ from ._exceptions import (
 from ._models import URL, Cookies, Headers, QueryParams, Request, Response
 from ._status_codes import StatusCode, codes
 from ._transports.asgi import ASGITransport
-from ._transports.urllib3 import URLLib3ProxyTransport, URLLib3Transport
 from ._transports.wsgi import WSGITransport
 
 __all__ = [
@@ -72,7 +70,6 @@ __all__ = [
     "NotRedirectResponse",
     "options",
     "patch",
-    "PoolLimits",
     "PoolTimeout",
     "post",
     "ProtocolError",
@@ -85,7 +82,6 @@ __all__ = [
     "RemoteProtocolError",
     "request",
     "Request",
-    "RequestBodyUnavailable",
     "RequestError",
     "RequestNotRead",
     "Response",
@@ -101,8 +97,6 @@ __all__ = [
     "TransportError",
     "UnsupportedProtocol",
     "URL",
-    "URLLib3ProxyTransport",
-    "URLLib3Transport",
     "WriteError",
     "WriteTimeout",
     "WSGITransport",
