@@ -55,7 +55,7 @@ class HTTPError(Exception):
         response = httpx.get("https://www.example.com")
         response.raise_for_status()
     except httpx.HTTPError as exc:
-        print(f"HTTP Exception for {exc.request.url} - {exc.message}")
+        print(f"HTTP Exception for {exc.request.url} - {exc}")
     ```
     """
 
@@ -207,13 +207,6 @@ class TooManyRedirects(RequestError):
     """
 
 
-class RequestBodyUnavailable(RequestError):
-    """
-    Had to send the request again, but the request body was streaming, and is
-    no longer available.
-    """
-
-
 # Client errors
 
 
@@ -283,14 +276,18 @@ class StreamError(Exception):
 
 class StreamConsumed(StreamError):
     """
-    Attempted to read or stream response content, but the content has already
+    Attempted to read or stream content, but the content has already
     been streamed.
     """
 
     def __init__(self) -> None:
         message = (
-            "Attempted to read or stream response content, but the content has "
-            "already been streamed."
+            "Attempted to read or stream some content, but the content has "
+            "already been streamed. For requests, this could be due to passing "
+            "a generator as request content, and then receiving a redirect "
+            "response or a secondary request as part of an authentication flow."
+            "For responses, this could be due to attempting to stream the response "
+            "content more than once."
         )
         super().__init__(message)
 
